@@ -20,7 +20,7 @@ samples from probability distributions for stochastic nodes in PyMC.
 import warnings
 
 from functools import singledispatch
-from typing import Optional, Sequence, Tuple, Union
+from typing import Any, Optional, Sequence, Tuple, Union, cast
 
 import numpy as np
 
@@ -28,11 +28,15 @@ from aesara import config
 from aesara import tensor as at
 from aesara.graph.basic import Variable
 from aesara.graph.op import Op, compute_test_value
+from aesara.raise_op import Assert
 from aesara.tensor.random.op import RandomVariable
 from aesara.tensor.shape import SpecifyShape
 from aesara.tensor.var import TensorVariable
 from typing_extensions import TypeAlias
 
+from pymc.aesaraf import convert_observed_data
+from pymc.model import modelcontext
+
 __all__ = [
     "to_tuple",
     "shapes_broadcasting",
@@ -657,3 +661,123 @@ def change_specify_shape_size(op, ss, new_size, expand) -> TensorVariable:
 
     # specify_shape has a wrong signature https://github.com/aesara-devs/aesara/issues/1164
     return at.specify_shape(new_var, new_shapes)  # type: ignore
+
+
+def get_support_shape(
+    support_shape: Optional[Sequence[Union[int, np.ndarray, TensorVariable]]],
+    *,
+    shape: Optional[Shape] = None,
+    dims: Optional[Dims] = None,
+    observed: Optional[Any] = None,
+    support_shape_offset: Sequence[int] = None,
+    ndim_supp: int = 1,
+) -> Optional[TensorVariable]:
+    """Extract the support shapes from shape / dims / observed information
+
+    Parameters
+    ----------
+    support_shape:
+        User-specified support shape for multivariate distribution
+    shape:
+        User-specified shape for multivariate distribution
+    dims:
+        User-specified dims for multivariate distribution
+    observed:
+        User-specified observed data from multivariate distribution
+    support_shape_offset:
+        Difference between last shape dimensions and the length of
+        explicit support shapes in multivariate distribution, defaults to 0.
+        For timeseries, this is shape[-1] = support_shape[-1] + 1
+    ndim_supp:
+        Number of support dimensions of the given multivariate distribution, defaults to 1
+
+    Returns
+    -------
+    support_shape
+        Support shape, if specified directly by user, or inferred from the last dimensions of
+        shape / dims / observed. When two sources of support shape information are provided,
+        a symbolic Assert is added to ensure they are consistent.
+    """
+    if ndim_supp < 1:
+        raise NotImplementedError("ndim_supp must be bigger than 0")
+    if support_shape_offset is None:
+        support_shape_offset = [0] * ndim_supp
+    elif isinstance(support_shape_offset, int):
+        support_shape_offset = [support_shape_offset] * ndim_supp
+    inferred_support_shape: Optional[Sequence[Union[int, np.ndarray, Variable]]] = None
+
+    if shape is not None:
+        shape = to_tuple(shape)
+        assert isinstance(shape, tuple)
+        if len(shape) < ndim_supp:
+            raise ValueError(
+                f"Number of shape dimensions is too small for ndim_supp of {ndim_supp}"
+            )
+        inferred_support_shape = [
+            shape[i] - support_shape_offset[i] for i in np.arange(-ndim_supp, 0)
+        ]
+
+    if inferred_support_shape is None and dims is not None:
+        dims = convert_dims(dims)
+        assert isinstance(dims, tuple)
+        if len(dims) < ndim_supp:
+            raise ValueError(f"Number of dims is too small for ndim_supp of {ndim_supp}")
+        model = modelcontext(None)
+        inferred_support_shape = [
+            model.dim_lengths[dims[i]] - support_shape_offset[i]  # type: ignore
+            for i in np.arange(-ndim_supp, 0)
+        ]
+
+    if inferred_support_shape is None and observed is not None:
+        observed = convert_observed_data(observed)
+        if observed.ndim < ndim_supp:
+            raise ValueError(
+                f"Number of observed dimensions is too small for ndim_supp of {ndim_supp}"
+            )
+        inferred_support_shape = [
+            observed.shape[i] - support_shape_offset[i] for i in np.arange(-ndim_supp, 0)
+        ]
+
+    # We did not learn anything
+    if inferred_support_shape is None and support_shape is None:
+        return None
+    # Only source of information was the originally provided support_shape
+    elif inferred_support_shape is None:
+        inferred_support_shape = support_shape
+    # There were two sources of support_shape, make sure they are consistent
+    elif support_shape is not None:
+        inferred_support_shape = [
+            cast(
+                Variable,
+                Assert(msg="support_shape does not match respective shape dimension")(
+                    inferred, at.eq(inferred, explicit)
+                ),
+            )
+            for inferred, explicit in zip(inferred_support_shape, support_shape)
+        ]
+
+    return at.stack(inferred_support_shape)
+
+
+def get_support_shape_1d(
+    support_shape: Optional[Union[int, np.ndarray, TensorVariable]],
+    *,
+    shape: Optional[Shape] = None,
+    dims: Optional[Dims] = None,
+    observed: Optional[Any] = None,
+    support_shape_offset: int = 0,
+) -> Optional[TensorVariable]:
+    """Helper function for cases when you just care about one dimension."""
+    support_shape_tuple = get_support_shape(
+        support_shape=(support_shape,) if support_shape is not None else None,
+        shape=shape,
+        dims=dims,
+        observed=observed,
+        support_shape_offset=(support_shape_offset,),
+    )
+
+    if support_shape_tuple is not None:
+        (support_shape_,) = support_shape_tuple
+        return support_shape_
+    else:
+        return None
