@@ -53,9 +53,10 @@ pymc/parallel_sampling.py
 pymc/plots/__init__.py
 pymc/sampling.py
 pymc/smc/__init__.py
-pymc/smc/sample_smc.py
-pymc/smc/smc.py
+pymc/smc/sampling.py
+pymc/smc/kernels.py
 pymc/stats/__init__.py
+pymc/stats/convergence.py
 pymc/step_methods/__init__.py
 pymc/step_methods/compound.py
 pymc/step_methods/hmc/__init__.py
